import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { Bit } from "../BitString/Bit.js";
import { BitVarying } from "../BitString/BitVarying.js";
import { Int2 } from "../Numeric/Int2.js";
import { Int4 } from "../Numeric/Int4.js";
import { Int8 } from "../Numeric/Int8.js";
import { OID } from "../ObjectIdentifier/OID.js";
import { UUID } from "../UUID/UUID.js";
import { CharacterVarying } from "./CharacterVarying.js";
import { Name } from "./Name.js";
import { Text } from "./Text.js";
interface CharacterObject {
    value: string;
}
interface Character<N extends number> {
    character: string;
    value: string;
    postgres: string;
    get n(): N;
    toString(): string;
    toJSON(): CharacterObject;
    equals(string: string): boolean;
    equals(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | UUID | CharacterObject): boolean;
    safeEquals(string: string): SafeEquals<Character<N>>;
    safeEquals(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | UUID | CharacterObject): SafeEquals<Character<N>>;
}
interface CharacterConstructor<N extends number> {
    from(string: string): Character<N>;
    from(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | UUID | CharacterObject): Character<N>;
    safeFrom(string: string): SafeFrom<Character<N>>;
    safeFrom(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | UUID | CharacterObject): SafeFrom<Character<N>>;
    /**
     * Returns `true` if `object` is a `Character`, `false` otherwise.
     */
    isCharacter(object: any): object is Character<N>;
    /**
     * Returns `true` if `object` is a `Character<N>`, `false` otherwise.
     */
    isCharacter<NN extends number = N>(object: any, n: NN): object is Character<NN>;
    /**
     * Returns `true` if `object` is a `Character<N>`, `false` otherwise.
     */
    isAnyCharacter(object: any): object is Character<number>;
    /**
     * Get a `Character` constructor for a specific `n`.
     * @param n The number of characters.
     */
    setN<N extends number = 1>(n: N): CharacterConstructor<N>;
    /**
     * Get the `n` value for this `Character` constructor.
     * @returns The `n` value.
     */
    get n(): N;
}
declare const Character: CharacterConstructor<1>;
export { Character, CharacterConstructor, CharacterObject };
