import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { Bit } from "../BitString/Bit.js";
import { BitVarying } from "../BitString/BitVarying.js";
import { Int2 } from "../Numeric/Int2.js";
import { Int4 } from "../Numeric/Int4.js";
import { Int8 } from "../Numeric/Int8.js";
import { OID } from "../ObjectIdentifier/OID.js";
import { UUID } from "../UUID/UUID.js";
import { Character } from "./Character.js";
import { Name } from "./Name.js";
import { Text } from "./Text.js";
interface CharacterVaryingObject {
    value: string;
}
interface CharacterVarying<N extends number> {
    characterVarying: string;
    value: string;
    postgres: string;
    get n(): N;
    toString(): string;
    toJSON(): CharacterVaryingObject;
    equals(string: string): boolean;
    equals(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | UUID | CharacterVaryingObject): boolean;
    safeEquals(string: string): SafeEquals<CharacterVarying<N>>;
    safeEquals(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | UUID | CharacterVaryingObject): SafeEquals<CharacterVarying<N>>;
}
interface CharacterVaryingConstructor<N extends number> {
    from(string: string): CharacterVarying<N>;
    from(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | UUID | CharacterVaryingObject): CharacterVarying<N>;
    safeFrom(string: string): SafeFrom<CharacterVarying<N>>;
    safeFrom(object: Bit<number> | BitVarying<number> | Character<number> | CharacterVarying<number> | Name | Text | Int2 | Int4 | Int8 | OID | UUID | CharacterVaryingObject): SafeFrom<CharacterVarying<N>>;
    /**
     * Returns `true` if `object` is a `CharacterVarying`, `false` otherwise.
     */
    isCharacterVarying(object: any): object is CharacterVarying<N>;
    /**
     * Returns `true` if `object` is a `CharacterVarying<N>`, `false` otherwise.
     */
    isCharacterVarying<N extends number = number>(object: any, n: N): object is CharacterVarying<N>;
    /**
     * Returns `true` if `object` is a `CharacterVarying<N>`, `false` otherwise.
     */
    isAnyCharacterVarying(object: any): object is CharacterVarying<number>;
    /**
     * Get a `CharacterVarying` constructor for a specific `n`.
     * @param n The number of characters.
     */
    setN<N extends number = number>(n: N): CharacterVaryingConstructor<N>;
    /**
     * Get the `n` value for this `CharacterVarying` constructor.
     * @returns The `n` value.
     */
    get n(): N;
}
declare const CharacterVarying: CharacterVaryingConstructor<number>;
export { CharacterVarying, CharacterVaryingConstructor, CharacterVaryingObject };
