import { DateTime, Zone } from "luxon";
import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
interface DateObject {
    year: number;
    month: number;
    day: number;
}
interface Date {
    year: number;
    month: number;
    day: number;
    value: number;
    postgres: string;
    toString(): string;
    toNumber(): number;
    toJSON(): DateObject;
    /**
     * @param zone The zone to convert the date to. Defaults to 'local'.
     */
    toDateTime(zone?: string | Zone | undefined): DateTime;
    /**
     * @param zone The zone to convert the date to. Defaults to 'local'.
     */
    toJSDate(zone?: string | Zone | undefined): globalThis.Date;
    equals(string: string): boolean;
    equals(unixTimestamp: number): boolean;
    equals(year: number, month: number, day: number): boolean;
    equals(date: Date | globalThis.Date | DateTime): boolean;
    equals(object: DateObject): boolean;
    safeEquals(string: string): SafeEquals<Date>;
    safeEquals(unixTimestamp: number): SafeEquals<Date>;
    safeEquals(year: number, month: number, day: number): SafeEquals<Date>;
    safeEquals(date: Date | globalThis.Date | DateTime): SafeEquals<Date>;
    safeEquals(object: DateObject): SafeEquals<Date>;
}
interface DateConstructor {
    from(string: string): Date;
    from(unixTimestamp: number): Date;
    from(year: number, month: number, day: number): Date;
    from(date: Date | globalThis.Date | DateTime): Date;
    from(object: DateObject): Date;
    safeFrom(string: string): SafeFrom<Date>;
    safeFrom(unixTimestamp: number): SafeFrom<Date>;
    safeFrom(year: number, month: number, day: number): SafeFrom<Date>;
    safeFrom(date: Date | globalThis.Date | DateTime): SafeFrom<Date>;
    safeFrom(object: DateObject): SafeFrom<Date>;
    /**
     * Returns `true` if `object` is a `Date`, `false` otherwise.
     */
    isDate(object: any): object is Date;
}
declare const Date: DateConstructor;
export { Date, DateConstructor, DateObject };
