import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { Point, PointObject } from "./Point.js";
declare enum Connection {
    open = "open",
    closed = "closed"
}
type ConnectionType = "open" | "closed";
interface PathObject {
    points: Point[];
    connection: Connection | ConnectionType;
}
interface RawPathObject {
    points: PointObject[];
    connection: Connection | ConnectionType;
}
interface Path {
    points: Point[];
    connection: Connection | ConnectionType;
    value: string;
    postgres: string;
    toString(): string;
    toJSON(): RawPathObject;
    equals(string: string): boolean;
    equals(points: Point[]): boolean;
    equals(point: Point, ...points: Point[]): boolean;
    equals(path: Path): boolean;
    equals(object: PathObject | RawPathObject): boolean;
    safeEquals(string: string): SafeEquals<Path>;
    safeEquals(points: Point[]): SafeEquals<Path>;
    safeEquals(point: Point, ...points: Point[]): SafeEquals<Path>;
    safeEquals(path: Path): SafeEquals<Path>;
    safeEquals(object: PathObject | RawPathObject): SafeEquals<Path>;
}
interface PathConstructor {
    from(string: string): Path;
    from(points: Point[]): Path;
    from(point: Point, ...points: Point[]): Path;
    from(path: Path): Path;
    from(object: PathObject | RawPathObject): Path;
    safeFrom(string: string): SafeFrom<Path>;
    safeFrom(points: Point[]): SafeFrom<Path>;
    safeFrom(point: Point, ...points: Point[]): SafeFrom<Path>;
    safeFrom(path: Path): SafeFrom<Path>;
    safeFrom(object: PathObject | RawPathObject): SafeFrom<Path>;
    /**
     * Returns `true` if `object` is a `Path`, `false` otherwise.
     */
    isPath(object: any): object is Path;
}
declare const Path: PathConstructor;
export { Connection, ConnectionType, Path, PathConstructor, PathObject, RawPathObject };
