import { getPgTPError } from "./throwPgTPError.js";
export const PgTPParser = (parser, isArray = false) => new PgTPParserClass(parser, isArray);
export class PgTPParserClass {
    constructor(parser, isArray) {
        this.parser = parser;
        this.isArray = isArray;
        this._nullable = false;
        this._optional = false;
    }
    nullable() {
        this._nullable = true;
        return this;
    }
    optional() {
        this._optional = true;
        return this;
    }
    isValid(data, inner = false) {
        if (data === null) {
            return !inner && this._nullable
                ? {
                    success: true,
                    data,
                }
                : {
                    success: false,
                    error: getPgTPError({
                        code: "invalid_type",
                        expected: "not null",
                        received: "null",
                    }),
                };
        }
        if (data === undefined) {
            return !inner && this._optional
                ? {
                    success: true,
                    data,
                }
                : {
                    success: false,
                    error: getPgTPError({
                        code: "invalid_type",
                        expected: "not undefined",
                        received: "undefined",
                    }),
                };
        }
        if (!inner && this.isArray) {
            if (!Array.isArray(data)) {
                return {
                    success: false,
                    error: getPgTPError({
                        code: "invalid_type",
                        expected: "array",
                        received: typeof data,
                    }),
                };
            }
            const successfull = [];
            for (const v of data) {
                const result = this.isValid(v, true);
                if (!result.success)
                    return result;
                successfull.push(result.data);
            }
            return {
                success: true,
                data: successfull,
            };
        }
        if (this.parser === "unknown") {
            return {
                success: true,
                data: data,
            };
        }
        return this.parser.safeFrom(data);
    }
}
//# sourceMappingURL=PgTPParser.js.map