import type { SafeEquals } from "../types/SafeEquals.js";
import type { SafeFrom } from "../types/SafeFrom.js";
import type { SafeIsWithinRange } from "../types/SafeIsWithinRange.js";
declare enum LowerRange {
    include = "[",
    exclude = "("
}
type LowerRangeType = "[" | "(";
declare enum UpperRange {
    include = "]",
    exclude = ")"
}
type UpperRangeType = "]" | ")";
interface RangeObject<DataType> {
    lower: LowerRange | LowerRangeType;
    upper: UpperRange | UpperRangeType;
    values: [DataType, DataType] | null;
}
interface RawRangeObject<DataTypeObject> {
    lower: LowerRange | LowerRangeType;
    upper: UpperRange | UpperRangeType;
    values: [DataTypeObject, DataTypeObject] | null;
}
interface Range<DataType, DataTypeObject> {
    lower: LowerRange | LowerRangeType;
    upper: UpperRange | UpperRangeType;
    values: [DataType, DataType] | null;
    readonly empty: boolean;
    value: string;
    postgres: string;
    toString(): string;
    toJSON(): RawRangeObject<DataTypeObject>;
    equals(string: string): boolean;
    equals(value: [DataType, DataType]): boolean;
    equals(value1: DataType, value2: DataType): boolean;
    equals(range: Range<DataType, DataTypeObject>): boolean;
    equals(data: RangeObject<DataType> | RawRangeObject<DataTypeObject>): boolean;
    safeEquals(string: string): SafeEquals<Range<DataType, DataTypeObject>>;
    safeEquals(value: [DataType, DataType]): SafeEquals<Range<DataType, DataTypeObject>>;
    safeEquals(value1: DataType, value2: DataType): SafeEquals<Range<DataType, DataTypeObject>>;
    safeEquals(range: Range<DataType, DataTypeObject>): SafeEquals<Range<DataType, DataTypeObject>>;
    safeEquals(data: RangeObject<DataType> | RawRangeObject<DataTypeObject>): SafeEquals<Range<DataType, DataTypeObject>>;
    isWithinRange(string: string): boolean;
    isWithinRange(datatype: DataType): boolean;
    isWithinRange(data: DataTypeObject): boolean;
    safeIsWithinRange(string: string): SafeIsWithinRange<DataType>;
    safeIsWithinRange(datatype: DataType): SafeIsWithinRange<DataType>;
    safeIsWithinRange(data: DataTypeObject): SafeIsWithinRange<DataType>;
}
interface RangeConstructor<DataType, DataTypeObject> {
    from(string: string): Range<DataType, DataTypeObject>;
    from(value: [DataType, DataType]): Range<DataType, DataTypeObject>;
    from(value1: DataType, value2: DataType): Range<DataType, DataTypeObject>;
    from(range: Range<DataType, DataTypeObject>): Range<DataType, DataTypeObject>;
    from(data: RangeObject<DataType> | RawRangeObject<DataTypeObject>): Range<DataType, DataTypeObject>;
    safeFrom(string: string): SafeFrom<Range<DataType, DataTypeObject>>;
    safeFrom(value: [DataType, DataType]): SafeFrom<Range<DataType, DataTypeObject>>;
    safeFrom(value1: DataType, value2: DataType): SafeFrom<Range<DataType, DataTypeObject>>;
    safeFrom(range: Range<DataType, DataTypeObject>): SafeFrom<Range<DataType, DataTypeObject>>;
    safeFrom(data: RangeObject<DataType> | RawRangeObject<DataTypeObject>): SafeFrom<Range<DataType, DataTypeObject>>;
    /**
     * Returns `true` if `object` is a `Range` of the same type as `this`, `false` otherwise.
     */
    isRange(object: any): object is Range<DataType, DataTypeObject>;
}
declare const getRange: <DataType extends {
    equals(other: DataType): boolean;
    toString(): string;
    toJSON(): DataTypeObject;
}, DataTypeObject>(object: any, isObjectFunction: (object: any) => object is DataType, identifier: string) => RangeConstructor<DataType, DataTypeObject>;
export { getRange, LowerRange, LowerRangeType, Range, RangeConstructor, RangeObject, RawRangeObject, UpperRange, UpperRangeType };
